@@ -15,13 +15,18 @@ local({
               "aumclast", "aumcall", "aumcinf.obs", "aumcinf.pred",
               "cmax", "cmin", "clast.obs", "clast.pred", "cav", "ctrough")) {
     ## Add the column to the interval specification
-    add.interval.col(name=paste(n, "dn", sep="."),
-                     FUN="pk.calc.dn",
-                     values=c(FALSE, TRUE),
-                     desc=paste("Dose normalized", n),
-                     formalsmap=list(parameter=n),
-                     depends=c(n))
-    PKNCA.set.summary(paste(n, "dn", sep="."),
-                      business.geomean, business.geocv)
+    add.interval.col(
+      name=paste(n, "dn", sep="."),
+      FUN="pk.calc.dn",
+      values=c(FALSE, TRUE),
+      desc=paste("Dose normalized", n),
+      formalsmap=list(parameter=n),
+      depends=c(n)
+    )
+    PKNCA.set.summary(
+      name=paste(n, "dn", sep="."),
+      description="geometric mean and geometric coefficient of variation",
+      point=business.geomean,
+      spread=business.geocv)
   }
 })
